==> haskell-http-client-tls-0.3.5.1-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.5.1
id: http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
key: http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Client.TLS
abi: b7fedf1dbbceb3c1d31bbd8753cf0992
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/http-client-tls-0.3.5.1
hs-libraries: HShttp-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
depends:
    base-4.10.0.0 data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    connection-0.2.8-DV3SXnPmo3U13Xbkb1AWD4
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    tls-1.4.0-DUjRpAMZEHBIySIXtFteXe bytestring-0.10.8.2
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    transformers-0.5.2.0 http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi
    memory-0.14.8-HEYe2msABjoBOvbV0yaOyF
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 containers-0.5.10.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=b4f1dc33e75c56b9a2dc645c2701b72a
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=92ae31af81259bf85e2a7ae30800ecfd
             connection-0.2.8-DV3SXnPmo3U13Xbkb1AWD4=9b1e55fb75633a0ef35744e87bd69d9e
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=06cb668c0e9e66cc22d17c21c1fa2e38
             tls-1.4.0-DUjRpAMZEHBIySIXtFteXe=a7621fceab779a5d105b15420084d72a
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=a56b20bddcd4f2f0090e82c4a91df92f
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=b05755a8562dd13d7429852f04c3b73b
             cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi=65764b15f83c82a01ed285cd69324f88
             memory-0.14.8-HEYe2msABjoBOvbV0yaOyF=92e862c72a81ac9c5b811b192e9d3acc
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=98ab8c145be258d01b7a6333e00858ed
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=0d8dbc66a8173770b7f27b72bc5a4600
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.5.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.5.1
id: http-client-tls-0.3.5.1-LB4pkcb8qGEBWLeuaQ6vBK
key: http-client-tls-0.3.5.1-LB4pkcb8qGEBWLeuaQ6vBK
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Client.TLS
abi: fff145c519aed09c53efdf73d9e0e8ff
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/http-client-tls-0.3.5.1
hs-libraries: HShttp-client-tls-0.3.5.1-LB4pkcb8qGEBWLeuaQ6vBK
depends:
    base-4.10.0.0 data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    connection-0.2.8-DMHF7pH68f1CIg10bEvXf6
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    tls-1.4.0-31ZRwpEukM6Jnw4JDFykbI bytestring-0.10.8.2
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    transformers-0.5.2.0 http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP
    memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 containers-0.5.10.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=b4f1dc33e75c56b9a2dc645c2701b72a
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=92ae31af81259bf85e2a7ae30800ecfd
             connection-0.2.8-DMHF7pH68f1CIg10bEvXf6=9467fc5429c846f7948079a05febbf83
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=06cb668c0e9e66cc22d17c21c1fa2e38
             tls-1.4.0-31ZRwpEukM6Jnw4JDFykbI=d165900e46d58203fb742e28667401d6
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=a56b20bddcd4f2f0090e82c4a91df92f
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=b05755a8562dd13d7429852f04c3b73b
             cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP=2aff2c890f2811a4d19d3ee0bfb54087
             memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ=95aa1eec1ee6d97d56ce509d22129a9d
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=98ab8c145be258d01b7a6333e00858ed
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=0d8dbc66a8173770b7f27b72bc5a4600
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
